==> haskell-hopenpgp-2.7.4.1-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.7.4.1
id: hOpenPGP-2.7.4.1-7aDCWNJWsQGIkGKaHb67gm
key: hOpenPGP-2.7.4.1-7aDCWNJWsQGIkGKaHb67gm
license: MIT
copyright: 2012-2018  Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: https://salsa.debian.org/clint/hOpenPGP
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)
category: Codec, Data
abi: 6bbf34fc12ce62bbf2dd46a2af6805a6
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
import-dirs: /usr/lib/ghc-8.6.4/site-local/hOpenPGP-2.7.4.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hOpenPGP-2.7.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hOpenPGP-2.7.4.1
hs-libraries: HShOpenPGP-2.7.4.1-7aDCWNJWsQGIkGKaHb67gm
depends:
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU
    asn1-encoding-0.9.5-KIcWSI2LcvrF1kf3kfNm3M
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC
    bifunctors-5.5.3-AyIkxCOarJfGjopzP9nnoA binary-0.8.6.0
    binary-conduit-1.3.1-6uawz9BXgRMDmNNL9X6OPh bytestring-0.10.8.2
    bzlib-0.5.0.5-8TMEZNLRAIMKxXCedq0SW1
    conduit-1.3.1.1-8MOrAYt7hu26dsIPZTK6mr
    conduit-extra-1.3.1.1-BXrck7NvskXJ2wP5ouqNhY containers-0.6.0.1
    crypto-cipher-types-0.0.9-EDnaq2zDyKz77VO2aVXtii
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    errors-2.3.0-1e1TIiTQmEX6EpFTXvT8Fs
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    incremental-parser-0.3.2.2-4a9VdVix01U7A2rrbpYN1Y
    ixset-typed-0.4.0.1-4bNitdxw3vN2jRVfT2Wqh1
    lens-4.17-9007cpgFhetJxFTlfQo2qw
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA
    nettle-0.3.0-2fnPd9woiMI99sXNZlCUqu
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    newtype-0.2-I9xMGod6wpEBsBPdaJXf9q
    openpgp-asciiarmor-0.1.1-HJCq4QOi3YH7t5TpkpZHBx
    prettyprinter-1.2.1-D3LgkONL8k3FCoPBb2R7Pv
    resourcet-1.2.2-6zBKJcCUqdeLbP1UFGIV0t
    split-0.2.3.3-DmDMlgWSMW26OczFIiZ5Gr text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hopenpgp-2.7.4.1-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.7.4.1
id: hOpenPGP-2.7.4.1-KyvCVLzrbS73QpYrzCOpTL
key: hOpenPGP-2.7.4.1-KyvCVLzrbS73QpYrzCOpTL
license: MIT
copyright: 2012-2018  Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: https://salsa.debian.org/clint/hOpenPGP
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)
category: Codec, Data
abi: 283e0bb21cd1e55b29d889c623cd1983
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
import-dirs: /usr/lib/ghc-8.6.5/site-local/hOpenPGP-2.7.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hOpenPGP-2.7.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hOpenPGP-2.7.4.1
hs-libraries: HShOpenPGP-2.7.4.1-KyvCVLzrbS73QpYrzCOpTL
depends:
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU
    asn1-encoding-0.9.5-KIcWSI2LcvrF1kf3kfNm3M
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC
    bifunctors-5.5.3-AyIkxCOarJfGjopzP9nnoA binary-0.8.6.0
    binary-conduit-1.3.1-7sRAq6vFKASHQ3S5XpT2KH bytestring-0.10.8.2
    bzlib-0.5.0.5-8TMEZNLRAIMKxXCedq0SW1
    conduit-1.3.1.1-IQr01ehJbIbFHxZqbcjBvx
    conduit-extra-1.3.1.1-9AIEqqUHeTdBpIhmz3EoB8 containers-0.6.0.1
    crypto-cipher-types-0.0.9-EDnaq2zDyKz77VO2aVXtii
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    errors-2.3.0-1e1TIiTQmEX6EpFTXvT8Fs
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    incremental-parser-0.3.2.2-q4zZHjE0a2RfKGwhp0GT
    ixset-typed-0.4.0.1-4bNitdxw3vN2jRVfT2Wqh1
    lens-4.17-KviXglNeqUtLtDpQmaOU3Y
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA
    nettle-0.3.0-2fnPd9woiMI99sXNZlCUqu
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    newtype-0.2-I9xMGod6wpEBsBPdaJXf9q
    openpgp-asciiarmor-0.1.1-HJCq4QOi3YH7t5TpkpZHBx
    prettyprinter-1.2.1-8KxJCNGUCaOFkQGh9SBK5J
    resourcet-1.2.2-6zBKJcCUqdeLbP1UFGIV0t
    split-0.2.3.3-DmDMlgWSMW26OczFIiZ5Gr text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
